.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth API reference.

******************************
Utility Package Reference
******************************

Contents:

.. toctree::
    :maxdepth: 2

    copybinfiles
    DictTree
    DirWalk
    ExecTimer
    FileBuffer
    FileStatus
    Histogram
    HtmlUtils
    PatternSearch
    RemoveDupeFiles
    XmlWrite
    archive
    bin_file_type
    gnuplot
        
    plot/index_plot
